"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Guid = void 0;
class Guid {
    constructor(str) {
        this.DASH = '-';
        this.DASH_REGEXP = /-/g;
        this.contentStr = str;
        this.contentInt = this.getNumberFromGuidString();
        if (!this.isValid()) {
            this.contentStr = Guid.emptyStr;
            this.contentInt = -1;
        }
    }
    static empty() {
        return new Guid();
    }
    static newGuid() {
        return new Guid(this.generate());
    }
    static isValid(str) {
        if (str) {
            return Guid.patternV4.test(str);
        }
        return false;
    }
    isValid() {
        if (this.contentStr) {
            return Guid.patternV4.test(this.contentStr);
        }
        return false;
    }
    isEmpty() {
        return this.contentStr === Guid.emptyStr;
    }
    equals(otherGuid) {
        return otherGuid && !!this.contentStr && otherGuid.toString().toLowerCase() === this.contentStr.toLowerCase();
    }
    toString() {
        var _a;
        return (_a = this.contentStr) !== null && _a !== void 0 ? _a : '';
    }
    toNumber() {
        var _a;
        return (_a = this.contentInt) !== null && _a !== void 0 ? _a : -1;
    }
    getNumberFromGuidString() {
        if (!this.contentStr || this.contentStr.indexOf(this.DASH) === -1) {
            return -1;
        }
        return Number('0x' + this.contentStr.replace(this.DASH_REGEXP, ''));
    }
    static generate() {
        return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
            var r = (Guid.generateRandomDecimal() * 16) | 0, v = c == 'x' ? r : (r & 0x3) | 0x8;
            return v.toString(16);
        });
    }
    static generateRandomDecimal() {
        const cryptoObj = Guid.getCryptoImplementation();
        return typeof cryptoObj !== 'undefined'
            ? cryptoObj.getRandomValues(new Uint32Array(1))[0] / Guid.MAX_INT_32
            : Math.random();
    }
    static getCryptoImplementation() {
        // @ts-ignore: msCrypto does not exists in window (only for IE11)
        return window.crypto || window.msCrypto;
    }
}
exports.Guid = Guid;
Guid.patternV4 = /^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[4][0-9a-fA-F]{3}-[89ab][0-9a-fA-F]{3}-[0-9a-fA-F]{12}$/i;
Guid.emptyStr = '00000000-0000-0000-0000-000000000000';
Guid.MAX_INT_32 = 4294967295;
